Skip to contents

Render the report into a zip file for the INBO website

Usage

inbo_website(path = ".")

Arguments

path

The path to the directory where the report is located

See also

Other utils: create_report()