Convert a data frame with author information to YAML format
Arguments
a data frame with author information. It should contain the columns:
given: the given name of the authorfamily: the family name of the authoremail: the email address of the author (optional)orcid: the ORCID of the author (optional)affiliation: the affiliation of the author (optional)
- corresponding
a logical value indicating whether the author is the corresponding author. If
TRUE, the email address of the author must be provided.