Create a template for a flandersqmd report
Arguments
- path
The folder in which to create the folder containing the report. Defaults to the current working directory. It also creates an RStudio project file in the report folder. When ran from RStudio, the project will be opened automatically in a new session.
- reportname
The folder name of the report. The location of the folder
reportnamedepends on the content ofpath. Whenpathis achecklist::checklistproject, you will find the new report atpath/source/reportname. Whenpathis achecklist::checklistpackage, you will find the new report atpath/inst/reportname. Otherwise you will find the new report atpath/reportname.- version
The version of the
flandersqmd-bookextension to use. Defaults to"main", which refers to the current version.- shortname
Deprecated. Use
reportnameinstead.
See also
Other utils:
inbo_website()