R/inbo_website.R
inbo_website.Rd
Render the report into a zip file for the INBO website
inbo_website(path = ".")
The path to the directory where the report is located
Other utils: create_report()
create_report()